Propagation

Enum Propagation 

pub enum Propagation {
    Propagate,
    Halt,
    FlushOut,
}
A return value used by CallbackTable/Callbacks callbacks to indicate whether to flag dependent signals as stale and optionally also refresh ones not currently subscribed.

Variants



Propagate

Mark at least directly dependent signals as stale.
The runtime decides whether and when to refresh them.



Halt

Do not mark dependent signals as stale because of this Propagation.



FlushOut

Asks the runtime to refresh dependencies, even those that are not subscribed.

This should be transitive through Propagate of dependents,
but should not be transitive through Halt.

Hint

Use this variant to purge heavy or reference-counted resources store in dependent signals.