pub enum Propagation {
Propagate,
Halt,
FlushOut,
}Expand description
A return value used by CallbackTable/Callbacks callbacks
to indicate whether to flag dependent signals as stale and optionally also refresh ones not currently subscribed.
Variants
Propagate
Mark at least directly dependent signals as stale.
The runtime decides whether and when to refresh them.
Halt
Do not mark dependent signals as stale because of this Propagation.
FlushOut